#
# spec file for package brltty
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tcl_version: %global tcl_version %(echo 'puts $tcl_version' | tclsh)}
%{!?tcl_sitearch: %global tcl_sitearch %{_libdir}/tcl/tcl%{tcl_version}}
%define api_version 0.7.0
%define sover 0_7
%define soname libbrlapi%{sover}

%define with_polkit 1

%if 0%{?suse_version} >= 1500
%define espeak    espeak-ng-compat
%define espeakdev espeak-ng-compat-devel
%else
%define espeak    espeak
%define espeakdev espeak-devel
%endif

Name:           brltty
Version:        6.0
Release:        lp152.2.3.1
# FIXME libbraille driver when libbraille is in factory
Summary:        Braille display driver for Linux/Unix
License:        LGPL-2.1-or-later
Group:          System/Daemons
Url:            https://brltty.app/

Source0:        https://brltty.app/archive/%{name}-%{version}.tar.xz
Source1:        README.SUSE
Patch0:         brltty-5.5-systemd-install.patch
Patch1:         brltty-alsa.patch

BuildRequires:  %{espeakdev}
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gpm-devel
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  jpackage-utils
BuildRequires:  libbraille-devel
BuildRequires:  ncurses-devel
BuildRequires:  ocaml
BuildRequires:  pkg-config
BuildRequires:  python3
BuildRequires:  python3-Cython
BuildRequires:  python3-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  tcl-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libusb-1.0)
%if %{?with_polkit}
BuildRequires:  pkgconfig(polkit-gobject-1)
%endif
BuildRequires:  pkgconfig(speech-dispatcher)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xt)
%{?systemd_ordering}
%define _udevdir %(pkg-config --variable udevdir udev)

%description
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.

%package driver-at-spi2
Summary:        AT-SPI 2 driver for BRLTTY
Group:          System/Daemons
Requires:       %{name} = %{version}
Supplements:    packageand(brltty:at-spi2-core)

%description driver-at-spi2
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.

This package contains the AT-SPI 2 screen driver.

%package driver-brlapi
Summary:        BrlAPI driver for BRLTTY
Group:          System/Daemons
Requires:       %{name} = %{version}
Supplements:    packageand(brltty:%{soname})

%description driver-brlapi
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.

This package contains the BrlAPI braille driver.

%package driver-libbraille
Summary:        Libbraille driver for BRLTTY
Group:          System/Daemons
Requires:       %{name} = %{version}
Supplements:    packageand(brltty:libbraille)

%description driver-libbraille
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.

This package contains the libbraille braille driver.

%package driver-espeak
Summary:        ESpeak driver for BRLTTY
Group:          System/Daemons
Requires:       %{name} = %{version}
Supplements:    packageand(brltty:%{espeak})

%description driver-espeak
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.

This package contains the eSpeak speech driver.

%package driver-speech-dispatcher
Summary:        Speech Dispatcher driver for BRLTTY
Group:          System/Daemons
Requires:       %{name} = %{version}
Supplements:    packageand(brltty:libspeechd2)

%description driver-speech-dispatcher
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.

This package contains the Speech Dispatcher speech driver.

%package driver-xwindow
Summary:        XWindow driver for BRLTTY
Group:          System/Daemons
Requires:       %{name} = %{version}
Supplements:    packageand(brltty:xorg-x11-server)

%description driver-xwindow
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.

This package contains the XWindow braille driver.

%package utils
Summary:        Braille display driver for Linux/Unix
Group:          System/Daemons
Requires:       %{name} = %{version}

%description utils
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.

This package contain various utilities related to BRLTTY.

%package -n xbrlapi
Summary:        X BrlAPI helper
Group:          System/Daemons
Requires:       %{name} = %{version}
Supplements:    packageand(%{soname}:xorg-x11-server)

%description -n xbrlapi
The xbrlapi utility is a helper to have BrlAPI work on a X system.

%package -n %{soname}
Summary:        Library to use BRLTTY from applications
Group:          System/Daemons
Requires(post): coreutils
Requires(post): shadow
Requires(post): util-linux
Recommends:     %{name}

%description -n %{soname}
BrlAPI is a service provided by the brltty daemon.

Its purpose is to allow programmers to write applications that take
advantage of a braille terminal in order to deliver a blind user
suitable information for his/her specific needs.

While an application communicates with the braille terminal, everything
brltty sends to the braille terminal in the application's console is
ignored, whereas each piece of data coming from the braille terminal is
sent to the application, rather than to brltty.

%package -n brlapi-devel
Summary:        Library to use BRLTTY from applications -- Development Files
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}

%description -n brlapi-devel
BrlAPI is a service provided by the brltty daemon.

Its purpose is to allow programmers to write applications that take
advantage of a braille terminal in order to deliver a blind user
suitable information for his/her specific needs.

While an application communicates with the braille terminal, everything
brltty sends to the braille terminal in the application's console is
ignored, whereas each piece of data coming from the braille terminal is
sent to the application, rather than to brltty.

%package -n brlapi-java
Summary:        Library to use BRLTTY from applications -- Java Bindings
Group:          System/Daemons
Requires:       java
Requires:       jpackage-utils

%description -n brlapi-java
BrlAPI is a service provided by the brltty daemon.

Its purpose is to allow programmers to write applications that take
advantage of a braille terminal in order to deliver a blind user
suitable information for his/her specific needs.

While an application communicates with the braille terminal, everything
brltty sends to the braille terminal in the application's console is
ignored, whereas each piece of data coming from the braille terminal is
sent to the application, rather than to brltty.

%package -n ocaml-brlapi
Summary:        Library to use BRLTTY from applications -- OCaml Bindings
Group:          System/Daemons
Requires:       ocaml

%description -n ocaml-brlapi
BrlAPI is a service provided by the brltty daemon.

Its purpose is to allow programmers to write applications that take
advantage of a braille terminal in order to deliver a blind user
suitable information for his/her specific needs.

While an application communicates with the braille terminal, everything
brltty sends to the braille terminal in the application's console is
ignored, whereas each piece of data coming from the braille terminal is
sent to the application, rather than to brltty.

%package -n python3-brlapi
Summary:        Library to use BRLTTY from applications -- Python Bindings
Group:          System/Daemons

%description -n python3-brlapi
BrlAPI is a service provided by the brltty daemon.

Its purpose is to allow programmers to write applications that take
advantage of a braille terminal in order to deliver a blind user
suitable information for his/her specific needs.

While an application communicates with the braille terminal, everything
brltty sends to the braille terminal in the application's console is
ignored, whereas each piece of data coming from the braille terminal is
sent to the application, rather than to brltty.

%package -n tcl-brlapi
Summary:        Library to use BRLTTY from applications -- Tcl Bindings
Group:          System/Daemons
Requires:       tcl

%description -n tcl-brlapi
BrlAPI is a service provided by the brltty daemon.

Its purpose is to allow programmers to write applications that take
advantage of a braille terminal in order to deliver a blind user
suitable information for his/her specific needs.

While an application communicates with the braille terminal, everything
brltty sends to the braille terminal in the application's console is
ignored, whereas each piece of data coming from the braille terminal is
sent to the application, rather than to brltty.

%lang_package

%prep
%autosetup -p1

%build
cp %{_sourcedir}/README.SUSE .
# Fix "wrong-file-end-of-line-encoding" rpmlint warning
sed -i 's/\r$//' Documents/Manual-BRLTTY/Portuguese/BRLTTY.txt

sed -i 's:/usr/bin/python:/usr/bin/python3:' ./Tables/Contraction/latex-access.ctb

modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find . -type f -regex ".*\.c\|.*\.cpp\|.*\.h" -exec sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" {} +
for i in -I%{_libdir}/jvm/java/include{,/linux}; do
      java_inc="$java_inc $i"
done
export PYTHON=/usr/bin/python3
%configure CPPFLAGS="$java_inc" \
        --with-install-root="%{buildroot}" \
        --libexecdir=%_libexecdir \
        --disable-stripping
make -j1 # not parallel build safe

%install
sed -i "s=/usr/libexec/brltty-systemd-wrapper=%_libexecdir/brltty-systemd-wrapper=" Autostart/Systemd/brltty@.service
make install install-systemd DESTDIR="%buildroot"
%find_lang %{name}
%if %{?with_polkit}
sed -i "s/#api-parameters Auth=polkit/api-parameters Auth=polkit/" Documents/brltty.conf
%endif
install -D -m644 Documents/brltty.conf %{buildroot}%{_sysconfdir}/brltty.conf
# ghost brlapi.key
touch %{buildroot}%{_sysconfdir}/brlapi.key
# Don't include source files in binary package
rm -f %{buildroot}%{_libdir}/ocaml/brlapi/brlapi.{mli,cmxa}
# Don't claim generic USB serial adapters (boo#1007652)
sed -i \
  -e 's/^ENV{PRODUCT}=="403\/6001\/\*"/#ENV{PRODUCT}=="403\/6001\/\*"/' \
  -e 's/^ENV{PRODUCT}=="10c4\/ea60\/\*"/#ENV{PRODUCT}=="10c4\/ea60\/\*"/' \
  -e 's/^ENV{PRODUCT}=="10c4\/ea80\/\*"/#ENV{PRODUCT}=="10c4\/ea80\/\*"/' \
  Autostart/Udev/rules
mkdir -p %{buildroot}%{_udevdir}/rules.d
install -m644 Autostart/Udev/rules %{buildroot}%{_udevdir}/rules.d/69-%{name}.rules
%if %{?with_polkit}
mkdir -p %{buildroot}%{_datadir}/polkit-1/actions
install -m 644 Authorization/Polkit/org.a11y.brlapi.policy %{buildroot}%{_datadir}/polkit-1/actions
%endif
rm %{buildroot}%{_libdir}/libbrlapi.a
rm %{buildroot}%{_libdir}/ocaml/brlapi/libbrlapi_stubs.a
rm %{buildroot}/etc/X11/Xsession.d/60xbrlapi # TODO: install this somewhere?
# fix missing executable bits
test ! -x %{buildroot}%{_bindir}/brltty-config
chmod a+x %{buildroot}%{_bindir}/brltty-config
# clean up the manuals:
rm Documents/Manual-*/*/{*.mk,*.made,Makefile*,*.sgml,*-[0-9]*.html}
mv Documents/BrlAPIref/html Documents/BrlAPIref/BrlAPIref
# group all the documentation in a doc subdirectory:
find . \( -path ./doc -o -path ./Documents \) -prune -o \
  \( -name 'README*' -o -name '*.txt' -o -name '*.html' -o \
     -name '*.sgml' -o -name '*.patch' -o \
     \( -path './Bootdisks/*' -type f -perm /ugo=x \) \) -print |
while read file; do
   mkdir -p doc/${file%/*} && cp -rp $file doc/$file || exit 1
done

# disable xbrlapi gdm autostart, there is already orca
rm -f %{buildroot}%{_datadir}/gdm/greeter/autostart/xbrlapi.desktop

install -Dm0644 Autostart/AppStream/org.a11y.brltty.metainfo.xml \
                %{buildroot}%{_datadir}/metainfo/org.a11y.brltty.metainfo.xml

%fdupes -s %{buildroot}%{_mandir}
%fdupes -s %{buildroot}

# fix brp-tcl wrong location for Tcl files
mkdir -p %{buildroot}%{tcl_sitearch}
mv %{buildroot}%{_libdir}/brlapi-%{api_version} %{buildroot}%{tcl_sitearch}/

%pre -n %{soname}
getent group brlapi >/dev/null || groupadd -r brlapi >/dev/null

%post -n %{soname}
if [ ! -e %{_sysconfdir}/brlapi.key ]; then
 mcookie > %{_sysconfdir}/brlapi.key
 chgrp brlapi %{_sysconfdir}/brlapi.key
 chmod 0640 %{_sysconfdir}/brlapi.key
fi
/sbin/ldconfig

%postun -n %{soname} -p /sbin/ldconfig

%pre
%service_add_pre %{name}.path

%post
%service_add_post %{name}.path

# Remove any messages that could've been in place about the upgrade
rm -f %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}-something

if [ -f /usr/bin/lsusb ]; then
  lsusb 2>/dev/null |grep -q 0403:6001
  if [ $? -eq 0 ]; then
    cat >> %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}-something << EOF

WARNING: The SUSE brltty package no longer enables certain USB
refreshable Braille displays by default, and it appears that you may have
one of these displays attached. If so, then you may need to edit
/usr/lib/udev/rules.d/69-brltty.rules.
If your device is a standard USB-to-serial converter, rather than a
refreshable Braille display, then you can ignore this message.
See /usr/share/doc/packages/brltty/README.SUSE for more information.

EOF
  fi
fi

%preun
%service_del_preun %{name}.path

%postun
%service_del_postun %{name}.path
# Remove the /var/adm updatemsg that was hand-created and thus not on filelist
rm -f %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}-something

%files
%defattr(-, root, root)
%doc LICENSE-LGPL README README.SUSE Documents/ChangeLog Documents/CONTRIBUTORS Documents/HISTORY Documents/README.Bluetooth Documents/TODO
%doc Documents/Manual-BRLTTY/English
%config(noreplace) %{_sysconfdir}/brltty.conf
%{_sysconfdir}/brltty/
%{_bindir}/brltty
%{_bindir}/brltty-atb
%{_bindir}/brltty-cldr
%{_bindir}/brltty-config
%{_bindir}/brltty-ctb
%{_bindir}/brltty-ktb
%{_bindir}/brltty-lscmds
%{_bindir}/brltty-lsinc
%{_bindir}/brltty-morse
%{_bindir}/brltty-trtxt
%{_bindir}/brltty-ttb
%{_bindir}/brltty-tune
%{_bindir}/eutp
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.a11y.%{name}.metainfo.xml
%if %{?with_polkit}
%{_datadir}/polkit-1/actions/org.a11y.brlapi.policy
%endif
%{_libdir}/brltty/
%{_libexecdir}/%{name}-systemd-wrapper
%{_mandir}/man1/brltty.1*
%{_mandir}/man1/eutp.1.gz
%{_udevdir}/rules.d/69-%{name}.rules
%{_unitdir}/%{name}.path
%{_unitdir}/%{name}@.path
%{_unitdir}/%{name}@.service
%exclude %{_libdir}/brltty/libbrlttybba.so
%exclude %{_libdir}/brltty/libbrlttyblb.so
%exclude %{_libdir}/brltty/libbrlttybxw.so
%exclude %{_libdir}/brltty/libbrlttyses.so
%exclude %{_libdir}/brltty/libbrlttyssd.so
%exclude %{_libdir}/brltty/libbrlttyxa2.so
%ghost %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}-something

%files driver-at-spi2
%defattr(-, root, root)
%{_libdir}/brltty/libbrlttyxa2.so

%files driver-brlapi
%defattr(-, root, root)
%doc Drivers/Braille/BrlAPI/README
%{_libdir}/brltty/libbrlttybba.so

%files driver-libbraille
%defattr(-, root, root)
%{_libdir}/brltty/libbrlttyblb.so

%files driver-espeak
%defattr(-, root, root)
%doc Drivers/Speech/eSpeak/README
%{_libdir}/brltty/libbrlttyses.so

%files driver-speech-dispatcher
%defattr(-, root, root)
%doc Drivers/Speech/SpeechDispatcher/README
%{_libdir}/brltty/libbrlttyssd.so

%files driver-xwindow
%defattr(-, root, root)
%doc Drivers/Braille/XWindow/README
%{_libdir}/brltty/libbrlttybxw.so

%files utils
%defattr(-, root, root)
%{_bindir}/vstp
%{_mandir}/man1/vstp.1*

%files -n xbrlapi
%defattr(-, root, root)
%{_bindir}/xbrlapi
%{_mandir}/man1/xbrlapi.1*

%files -n %{soname}
%defattr(-, root, root)
%doc Documents/Manual-BrlAPI/
%{_libdir}/libbrlapi.so.*
%ghost %{_sysconfdir}/brlapi.key

%files -n brlapi-devel
%defattr(-, root, root)
%doc Documents/BrlAPIref/BrlAPIref/
%{_includedir}/brltty/
%{_includedir}/brlapi*.h
%{_libdir}/libbrlapi.so
%doc %{_mandir}/man3/brlapi_*

%files -n brlapi-java
%defattr(-, root, root)
%{_jnidir}/libbrlapi_java.so
%{_javadir}/brlapi.jar

%files -n ocaml-brlapi
%defattr(-, root, root)
%{_libdir}/ocaml/brlapi/
%{_libdir}/ocaml/stublibs/dllbrlapi_stubs.so*

%files -n python3-brlapi
%defattr(-, root, root)
%{python3_sitearch}/brlapi.cpython*.so
%{python3_sitearch}/Brlapi-*.egg-info

%files -n tcl-brlapi
%defattr(-, root, root)
%{tcl_sitearch}/brlapi-%{api_version}/

%files lang -f %{name}.lang
%defattr(-, root, root)
%doc Documents/Manual-BRLTTY/French
%doc Documents/Manual-BRLTTY/Portuguese

%changelog
* Wed Oct 14 2020 Michael Gorse <mgorse@suse.com>
- Add coreutils and util-linux to post requires (boo#1177656).
* Wed Oct  9 2019 ro@suse.de
- change udev rule again to also not automatically use the braille
  driver for USB IDs 10c4:ea60 and 10c4:ea80 as these are generic
  IDs of generic UART bridges and should not be used for higher
  level devices (bsc#1093378, bsc#1093455, bsc#1007652)
* Wed Jun 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  allow OBS to shortcut by using systemd-devel-mini.
* Tue Mar 26 2019 olaf@aepfle.de
- Use alsa API properly. Consumers are expected to use
  <alsa/asoundlib.h> instead of <asoundlib.h>.
  This is in preparation of an change to pkgconfig(alsa) to
  not pollute CFLAGS with -I/usr/include/alsa anymore (bsc#1130333)
  brltty-alsa.patch
* Thu Feb 28 2019 mgorse@suse.com
- Update to version 6.0:
  + Too many changes; please read ChangeLog :
  - Rebased brltty-5.5-systemd-install.patch
- api_version is now 0.7.0, and sover is now 0_7
- brltty-systemd-wrapper now installs into /usr/libexec
- Pass libexecdir in configure
- LICENSE-GPL no longer exists
- Package binaries new in 6.0
* Tue May 15 2018 ro@suse.de
- use brltty.path for systemd macros (boo#1074096 again)
* Mon Mar 12 2018 aloisio@gmx.com
- Use correct license
* Mon Mar  5 2018 aloisio@gmx.com
- Update to version 5.6
  * General updates:
    + BRLTTY has been relicensed to the LGPL (from the GPL).
    + Better cursor routing handling of status line updates and
    vertical scrolling.
    + The Track Screen Scroll setting has been added.
    + The Word Wrap setting has been added.
    + Panning left when using a contraction table now word wraps.
    + Typing dismisses an alert message.
    + The test for when INFO does text maximization instead has
    been fixed.
    + Overrides are now applied when the preferences haven't yet
    been saved.
    + The Inceptor braille driver (from Innovision) has been added.
  * The Baum braille driver:
    + On models with B9 and B10 by the joystick, both are
    interpreted as Space.
    + Input packet handling for Pronto! V3 models has been fixed.
  * The EuroBraille braille driver:
    + Improved autodetection when using Bluetooth.
    + The Esytime braille keyboard can be used over Bluetooth and
    USB.
    + For Esytime models, B5 has been renamed to B8.
  * The HIMS braille driver:
    + The Smart Beetle is now recognized when using Bluetooth.
  * The HumanWare braille driver:
    + The BrailleNote Touch is recognized when using USB.
  * BrlAPI changes:
    + The version is now 0.6.7 (it was 0.6.6).
    + The brlapi_getModelIdentifier() function has been added to
    the API.
    + The default character set is now based on the user's locale.
    + Sessions would occasionally hang when connecting.
    + PolKit authentication is no longer attempted when it isn't
    available.
    + Reading raw key codes no longer uses key ranges.
  * Text tables:
    + The lt (Lithuanian) table has been updated.
    + The uk (Ukrainian) table has been added.
  * Contraction tables:
    + The fr-abrege (French) table has been updated.
    + The lt (Lithuanian) table has been added.
    + Support has been added for LibLouis tables.
    + brltty-ctb's output is now UTF-8 (rather than ASCII).
  * Key tables:
    + The ifPlatform and ifNotPlatform directives have been added.
  * Systemd changes:
    + Path (rather than target) units are now used to manage BRLTTY
    instances.
  * Build features:
    + Add the reload target to the make files for Systemd and Udev.
    + A make file for install/uninstall of the AppStream rules has
    been added.
    + Python 3.6 is supported.
- Use espeak-ng when available
* Wed Jan  3 2018 mgorse@suse.com
- Fix %%pre, %%post, and %%postun: brltty.service is now
  brltty@.service (boo#1074096).
* Tue Dec  5 2017 cbosdonnat@suse.com
- Drop python2 dependency (fate#323526)
* Fri Sep  1 2017 mgorse@suse.com
- Update to version 5.5
  +  HandyTech's Actilino is supported.
  +  HumanWare's Braille Note Touch is supported.
  +  The Orbit 20 is supported.
  + Various other changes; please read ChangeLog :
- Drop brltty-udev-rule.patch, brltty-polkit-fixes.patch,
  brltty-5.0-speechd.diff,
  brltty-5.4-latex-tables-executable.patch,
  brltty-braillenote-usb.patch, brltty.format-error.patch,
  brltty.makedev.patch, and brltty.ocaml.patch: fixed upstream.
- Add brltty-5.5-systemd-install.patch: fix systemd service
  directory on lib64
- polkit policy is now named org.a11y.brlapi.policy
- API version is now 0.6.6
- Don't create rcbrltty (why were we symlinking a systemd unit
  file here? Seems wrong)
* Thu Aug 10 2017 olaf@aepfle.de
- Update filename in /var/adm/update-messages to match documentation,
  and build-compare pattern
* Tue Jul 18 2017 olaf@aepfle.de
- Provide caml__frame with brltty.ocaml.patch
* Fri Jun  9 2017 tchvatal@suse.com
- Require java-devel >= 1.6 to not fail during bootstrapping
* Tue Mar 21 2017 mgorse@suse.com
- Replace brltty.format-error.patch with the upstream fix; our
  current patch doesn't appear to be sufficient (boo#1030240).
* Tue Mar 21 2017 olaf@aepfle.de
- Add -Wformat to work around build failure (boo#1030240)
  Add brltty.format-error.patch
  Add brltty.makedev.patch
* Tue Feb 14 2017 mgorse@suse.com
- Disable udev rule for generic FTDI devices to avoid taking
  USB-to-serial converters (boo#1007652). Add an update
  message if one of these devices is detected.
- Add a README.SUSE.
- Add brltty-polkit-fixes.patch:  don't delay brltty if waiting
  for polkit initialization, and fix polkit+key authentication
  (bsc#930242).
- Add brltty-braillenote-usb.patch: autodetect BrailleNote via
  USB.
- Always enable polkit (intention of the conditional was to
  disable on 13.2 and 42.1, but it was being disabled under 42.2
  as well).
* Mon Nov  7 2016 olaf@aepfle.de
- Fix syntax error in rule files
  brltty-udev-rule.patch
* Fri Sep 16 2016 mgorse@suse.com
- Update to version 5.4
  + Too many changes; please read ChangeLog :
- Drop b40-1.patch, brltty-polkit.patch, and
  brltty-5.3.1-udev-systemd.patch: fixed upstream.
- Add brltty-5.4-latex-tables-executable.patch: LaTeX tables
  should be executable.
- API version is now 0.6.5
- Install rules file into %%{_udevdir}/rules.d
- Install systemd files via the Makefile
- Make polkit a conditional.
* Thu Sep 15 2016 mgorse@suse.com
- Install polkit file (bsc#930242).
- Add brltty-5.3.1-udev-systemd.patch: fix udev rules to work with
  systemd. From upstream.
* Sun Jun 19 2016 jengelh@inai.de
- Add missing service_add_pre call. Add missing argument to fdupes.
- Fix misplacement of /69-brltty.rules in the root directory
  because pkgconfig(udev) was not requested, which led to _udevdir
  being the empty string.
* Tue Jun  7 2016 mgorse@suse.com
- Update to version 5.3.1 (fate#320893).
  + Too many changes; please read ChangeLog :
    usr/share/doc/packages/brltty/ChangeLog
- API version is now 0.6.4
- Require systemd to build
- Install brltty-atb, brltty-ktb, and brltty-tune (new binaries)
- Add b40-1.patch - fix for invalid packets from a Brailliant
- Add brltty-polkit.patch: support polkit-based authentication for brlapi.
  Install policy file
  Set polkit as default brlapi authentication mechanism
- Install udev rules
* Tue Feb 10 2015 mgorse@suse.com
- Modify systemd service file to correct brltty path (boo#917176).
* Tue Dec 23 2014 p.drouand@gmail.com
- Add a dependency to python3 for building; brltty fails in his staging
  project because of mssing python3-xml module
* Fri Dec 19 2014 p.drouand@gmail.com
- Update to version 5.2
  + Too many changes; please read ChangeLog :
    usr/share/doc/packages/brltty/ChangeLog
- API version is now 0.6.3
- Remove obsolete patches;
  + brltty-python-prefix.patch
  + brltty-5.1-fix-bashisms.patch
* Sun Nov 16 2014 Led <ledest@gmail.com>
- fix bashisms in brltty-install script
- add patches:
  * brltty-5.1-fix-bashisms.patch
* Sun Oct 19 2014 crrodriguez@opensuse.org
- Replace xorg-x11-devel by specific individual pkgconfig()
  buildrequires.
* Thu Jul 24 2014 mgorse@suse.com
- Remove byacc. Doesn't appear to be needed or used.
- Capitalize summary for driver-espeak.
* Fri Jun  6 2014 mgorse@suse.com
- Update to version 5.1
  + Various changes. See ChangeLog.
- API version is now 0.6.2
- Build Python 3 bindings, rather than Python 2 bindings.
* Mon May 19 2014 schwab@suse.de
- remove ocaml conditional, it is always available now
- don't fail if brlapi.cmxa wasn't built
* Sat Mar  1 2014 p.drouand@gmail.com
- Update to version 5.0
  + Too many changes; please read ChangeLog :
    usr/share/doc/packages/brltty/ChangeLog
- Define a sover and soname macro for further easy API number changes
- Use download Url as source
- Remove brltty-java-jni-dir.patch and brltty-cppflags.patch; no longer
  needed
- Add byacc and linux-glibc-devel requires; new upstream dependencies
- Replace pyrex with python-Cython build require; upstream change
- Create brlapi.key file; now needed to access to brlapi; fix rhbz#1010656
- Create an associated user
- Add shadow dependency; needed to create user
- Adapt brltty-speechd.diff to upstream changes
- Add systemd support to allow users to start brltty at startup
* Fri Jan 10 2014 mgorse@suse.com
- Remove AT-SPI 1 driver; superseded by AT-SPI 2 since GNOME 3.0.
* Tue Oct 29 2013 fcrozat@suse.com
- Fix build:+ no longer rely on deprecated function (-perm +...) in
  find.
- No longer use --disable-static, not supported in configure.
* Tue Jun 25 2013 tchvatal@suse.com
- Adjust the patch application to be same like with other patches.
* Tue Jun 18 2013 jengelh@inai.de
- Add brltty-speechd.diff to avert packaging failure and take
  into account changed speechd location.
- More robust make install call. Remove redundant %%clean section.
* Sun Mar 24 2013 schwab@suse.de
- Don't build ocaml bindings on aarch64
* Sun Apr 15 2012 simone.tolotti@gmail.com
- Update to version 4.3:
  +  New options:
    The -F [--speech-fifo=] option has been renamed to -i [--speech-input=].
    The -F [--preferences-file=] option sets the path to the preferences file.
    The -L [--log-file=] brltty option writes timestamped logs to a file.
    The -q [--quiet] xbrlapi option suppresses the displaying of window titles.
    The -r [--reformat-text] ctbtest option joins unindented input lines.
    The log level can now be specified within brltty.conf.
  +  New device support:
    A braille driver for BrailComm displays has been added.
    The HandyTech braille driver now supports the Active Braille.
    The Voyager braille driver now supports the part 232 serial adapter.
    The Voyager braille driver now supports the Braille Pen (aka Easy Link).
  +  Preferences menu changes:
    The preference selections now apply to the preferences menu itself, too.
    Keyboard key bindings now work correctly within the preferences menu.
    The "Text Style" preference has new settings:
    8-Dot Computer Braille (formerly 8-dot)
    Contracted Braille (formerly 6-dot)
    6-Dot Computer Braille
    The "Expand Current Word" preference has been added.
    It's only visible if "Text Style" is set to "Contracted Braille".
    It can be set to:
    Yes (don't contract the word the cursor is on)
    No (contract the whole line)
    The "Capitalization Mode" preference has been added.
    It's only visible if "Text Style" is set to "Contracted Braille".
    It can be set to:
    No Capitalization
    Use Capital Sign
    Superimpose Dot 7
  +  General changes:
    Internationalization support has been improved.
    French and German translations have been added.
    Support for multi-byte local character sets has been improved.
    Horizontal window motions now work correctly with contracted braille.
    The half window left motion no longer can move to a bad location.
    Alert messages no longer disappear unexpectedly.
    The speech FIFO is now created relative to the current working directory.
    Serial flow control is now enabled before device probing.
    The following global variables for use within tables are now predefined:
    tablesDirectory
    tableExtension
    subtableExtension
  +  Alva braille driver changes:
    The BC key bindings have been changed significantly in order to add
    more functions and to support the USB640 (which has no smartpad).
    The braille keyboard of the BC Feature Pack is now supported.
  +  Baum braille driver changes:
    Updating the text and status cells of the Vario 80 has been fixed.
    The front and command keys of the Vario 80 are now supported.
  +  EuroBraille braille driver changes:
    Reading keys is faster and no longer generates spurious input errors.
  +  HandyTech braille driver changes:
    Support for the Active Braille has been added.
    The help screen now describes how the keypad keys are named.
  +  Papenmeier braille driver changes:
    The initial state of the switches and keys of EL models is detected.
  +  Seika braille driver changes:
    The help screen now describes the key layout.
  +  TTY braille driver changes:
    A few more key bindings have been defined.
  +  Voyager braille driver changes:
    Serial support has been added.
    Bluetooth support has been added.
    Support for the part 232 serial adapter has been added.
    Support for the Braille Pen (aka Easy Link) has been added.
  +  XWindow braille driver changes:
    More and less restrictive fonts are supported.
    Hard program exits have been removed.
  +  eSpeak speech driver changes:
    The full advertized speech rate range can now be used.
  +  FestivalLite speech driver changes:
    The default voice has been changed to kal (from kal16).
  +  AtSpi screen driver changes:
    No more annoying warnings when not on an AtSpi widget.
  +  BrlAPI fixes:
    ISO-8859-1 is now accepted as a character set when iconv isn't available.
    The autorepeat flags are now handled on a per session basis.
    Commands are now processed when the device is released.
  +  WindowEyes BrlAPI driver changes:
    Testing for BrlAPI open errors has been improved.
  +  Text table changes:
    A common subtable for the block characters has been added.
    The glyph directive has been added.
    Several alternate fonts for the Latin letters are now defined.
    If a character isn't defined then check for an alternative which is:
    (its Unicode base character, its iconv-defined ASCII equivalent, etc).
    The en_UK text table has been renamed to en_GB (to comply with ISO 3166).
    Updated text tables:
    bo (Tibetan)
    brf: dot 7 is no longer presented
    fr_FR (French France)
    fr-vs (French table used by VisioBraille devices)
    is (Icelandic): updated to the newly adopted standard
  +  Contraction table changes:
    If a zero-width character isn't defined then don't show it.
    Updated tables:
    de-kurzschrift (German)
    en-us-g2 (American English)
    es (Spanish)
    fr-abrege (French)
    zh-tw (Taiwanese Chinese)
  +  Key table changes:
    A specific key within a set can now be specified by number.
    A key combination can now include specific keys which aren't in set 0.
    Keys which aren't in set 0 can now be mapped to keyboard functions.
    A key set name can now be used to define a hotkey.
    The help text no longer includes hidden hotkeys.
    The help text now handles context-specific hotkeys correctly.
    The note directive now supports the use of variables.
  +  Windows changes:
    Serial devices beyond COM9 may now be specified.
    The WindowEyes driver is now copied into the correct installation directory.
  +  Build changes:
    Building an exported (not checked out) copy now "knows" its revision number.
    Make support for install/uninstall of /usr/share/doc/brltty has been added.
    The make targets for source archives are now prefixed with "src-".
    The bin-tar, bin-tar-gzip, and bin-tar-bzip2 make targets have been added.
    Support for xz compression of binary and source archives has been added.
    The preferences file has been moved to /var/lib/brltty/brltty.prefs.
    There's now only one preferences file (instead of one per braille driver).
    The preferences file is now text-based (instead of binary).
    The "writable" directory has been moved to /var/run/brltty.
    The "library" directory is now known as the "drivers" directory.
    The "data" directory no longer has a use and has been removed.
    Support for the "gjar" command has been added.
- Fixed tcl bindings failing in brp-tcl
* Sun Aug  7 2011 meissner@suse.de
- remove subversion buildrequries ... Seems unused.
* Mon Jun  6 2011 aj@suse.de
- Add patch brltty-header.patch to fix build with newer glibc
  due to missing sys/stat.h include.
* Tue May 24 2011 crrodriguez@opensuse.org
- remove timestamps from binaries, breaks build-compare
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 4.2:
  + Ending a cut operation beyond the right edge of the screen has
    been fixed.
  + Key/character insertion works with newer versions of Xorg.
  + The braille driver help files have been converted to plain
    text.
  + Multiple instances of brltty may not use the same PID file.
  + The keypad keyboard key table provides a braille input mode.
  + The working directory is no longer set to the data directory.
  + The writable directory is created if it doesn't already exist.
  + USB I/O via libusb1 is supported.
  + The Metec braille driver has been added.
  + The eSpeak speech driver has been added.
  + The AtSpi2 screen driver has been added.
  + A BrlAPI client for Window-Eyes has been developed.
  + Driver changes:
  - Converted drivers to use key tables.
  + Albatross braille driver changes:
  - USB support has been added.
  + Baum braille driver changes:
  - Vario Pro wheels are supported.
  - For Vario Pro models, only update the text cells which have
    changed.
  + FreedomScientific braille driver changes:
  - Bluetooth support has been added.
  - The Focus Blue is supported.
  - Rockers and bumper bars are recognized as distinct keys.
  + HandyTech braille driver changes:
  - Pressing two routing keys simultaneously immediately cuts the
    selected text.
  - Newer models which use the USB HID interface are supported.
  - The InputMode= parameter has been removed.
  + Papenmeier braille driver changes:
  - The DebugReads= and DebugWrites= parameters have been
    removed.
  - Support for the configuration file has been removed (now uses
    key tables).
  + BrlAPI changes:
  - Key event support has been added.
  - Various client fixes for the Windows environment.
  - Various fixes for when threads aren't available.
  - No more extraneous connection to localhost when using a
    TCP/IP host name.
  - A fix to exception handling within the Python bindings.
  + ExternalSpeech speech driver changes:
  - Two-letter driver identification code changed to "xs" (from
    "es").
  + AtSpi screen driver changes:
  - Static linking is supported.
  - A problem causing crashes on 64-bit platforms has been
    resolved.
  + Windows screen driver changes:
  - Significant reductions in memory usage.
  - Better handling of unreadable screens.
  - Better handling of the Alt+Tab window.
  + DOS changes:
  - Log records are written to the file "brltty.log".
  - The TSI braille driver stays at 9600 baud.
  + Key table changes:
  - Add the following directives: assign, context, hide, hotkey,
    ifkey, map, note, superimpose, title.
  - Add the \{name} variable name expansion syntax.
  - Add the ! immediate key syntax.
  - A command may have more than one modifier.
  - The line command modifiers are supported.
  - Keyboard key table names are now prefixed with "kbd-".
  - The ktbtest tool has been added.
  + Linux changes:
  - USB device inspection is more efficient.
  - Fixes to keyboard connect/disconnect monitoring.
  - Fixes to key event handling.
  - PCM and MIDI support defaults to ALSA (instead of to OSS).
  + Some windows changes.
  + Text tables updated: hu, sk.
  + Contraction tables updated: de-kurzschrift, en-us-g2, zh-tw.
- Add dbus-1-devel (for at-spi2 screen driver), espeak-devel (new
  speech driver), libusb-1_0-devel BuildRequires.
- Create driver-at-spi2 and driver-espeak subpackages, for the new
  drivers.
- Fix driver subpackages: for some reason, the files were not put
  in the right subpackages.
* Tue Sep  7 2010 aj@suse.de
- BuildRequire gpm-devel
* Wed Jun  2 2010 coolo@novell.com
- disable parallel make to fix build
* Thu Apr  8 2010 vuntz@opensuse.org
- Build libbraille driver.
* Fri Apr  2 2010 vuntz@opensuse.org
- Build Speech Dispatcher driver.
* Thu Apr  1 2010 vuntz@opensuse.org
- New package.
